This package contains the resources file Version.class compiled from Version.java with:

``` console
javac -source 1.2 -target 1.1 Version.java
```

This is used by the python Distribution class in this package to test the java distribution version
in a controlled manner.
